'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hash = exports.isSet = exports.isNumeric = exports.urlEncode = exports.urlDecode = exports.detectType = exports.validateEmail = exports.base64Encode = exports.base64Decode = undefined;

var _crypto = require('crypto');

var _crypto2 = _interopRequireDefault(_crypto);

var _mimeTypes = require('mime-types');

var _mimeTypes2 = _interopRequireDefault(_mimeTypes);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Base64 decode string
 * @param {String} str 
 */
var base64Decode = function base64Decode(str) {
  return new Buffer(str, 'base64').toString('utf8');
};

/**
 * Base64 encode string
 * @param {String} str 
 */
var base64Encode = function base64Encode(str) {
  return new Buffer(str).toString('base64');
};

/**
 * Encode URL
 * @param {String} str 
 */
var urlEncode = function urlEncode(str) {
  return encodeURIComponent(str);
};

/**
 * Decode URL
 * @param {String} str 
 */
var urlDecode = function urlDecode(str) {
  return decodeURIComponent(str);
};

/**
 * Hash string based on algorithm
 * @param {String} str 
 * @param {String} algorithm 
 */
var hash = function hash(str) {
  var algorithm = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'md5';
  return _crypto2.default.createHash(algorithm).update(str).digest("hex");
};

/**
 * Check if provided string is an email or not
 * @param {String} str 
 */
var validateEmail = function validateEmail(str) {
  var emailReg = /^([\w-]+(?:\.[\w-]+)*)@((?:[\w-]+\.)*\w[\w-]{0,66})\.([a-z]{2,6}(?:\.[a-z]{2})?)$/i;
  return emailReg.test(str);
};

/**
 * Detect string type
 * String can ba path to file as well
 * @param {String} str 
 */
var detectType = function detectType(str) {
  var extension = _path2.default.extname(str) || str;
  return _mimeTypes2.default.lookup(extension);
};

/**
 * Check if a string is numeric or not
 * @param {String} str 
 */
var isNumeric = function isNumeric(str) {
  return !isNaN(parseFloat(str)) && isFinite(str);
};

/**
 * Check if input is set or not (has a value even if empty)
 * @param {String} str 
 */
var isSet = function isSet(str) {
  return typeof str !== "undefined";
};

exports.base64Decode = base64Decode;
exports.base64Encode = base64Encode;
exports.validateEmail = validateEmail;
exports.detectType = detectType;
exports.urlDecode = urlDecode;
exports.urlEncode = urlEncode;
exports.isNumeric = isNumeric;
exports.isSet = isSet;
exports.hash = hash;